/**
 * Copyright 2021-2023 InPost S.A.
 *
 * NOTICE OF LICENSE
 *
 * Licensed under the EUPL-1.2 or later.
 * You may not use this work except in compliance with the Licence.
 *
 * You may obtain a copy of the Licence at:
 * https://joinup.ec.europa.eu/software/page/eupl
 * It is also bundled with this package in the file LICENSE.txt
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the Licence is distributed on an AS IS basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions
 * and limitations under the Licence.
 *
 * @author    InPost S.A.
 * @copyright 2021-2023 InPost S.A.
 * @license   https://joinup.ec.europa.eu/software/page/eupl
 */
$(() => {
  const orderErrorsBlockClass = 'js-inpost-method-error';

  const buildErrorsBlock = (messages) => {
    messages = $.map(messages, (message) => `<li>${message}</li>`).join('');

    return `<div class="${orderErrorsBlockClass}">
      <ul class="alert alert-danger">
        ${messages}
      </ul>
    </div>`;
  }

  const scrollToBlock = ($block) => $('html, body').animate({
    scrollTop: $block.offset().top
  }, 500);

  const showErrors = (messages, $appendTo) => {
    $appendTo.prepend(buildErrorsBlock(messages));
    scrollToBlock($appendTo);
  }

  const eraseErrors = () => {
    $(`.${orderErrorsBlockClass}`).remove();
  }

  const areInputsValid = ($wrapper) => {
    let valid = true;

    $wrapper.find(':input').each((index, input) => {
      if (!$(input).val()) {
        valid = false;

        return false;
      }
    });

    return valid;
  }

  $(document).on('click', '.steco_confirmation_btn', (e) => {
    e.preventDefault();
    eraseErrors();

    const $contentWrapper = $('.js-inpost-shipping-container:visible');

    if ($contentWrapper.length > 0 && !areInputsValid($contentWrapper)) {
      e.stopPropagation();
      e.stopImmediatePropagation();
      const formData = new FormData();

      formData.append('action', 'updateChoice');
      $contentWrapper.find(':input').each((index, element) => {
        const $input = $(element);
        formData.append($input.attr('name'), $input.val());
      });

      $.ajax({
        async: false,
        method: 'post',
        url: inPostAjaxController,
        data: formData,
        processData: false,
        contentType: false,
        dataType: 'json',
        success: (response) => {
          if (false === response.success && response.errors) {
            showErrors(response.errors, $contentWrapper);
          }
        }
      });
    }
  })
});
